==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adreça dau voastre sit', # MODIF
	'form_pet_aucune_signature' => 'Minga de signatura correspoande à-n-aqueu còde...', # MODIF
	'form_pet_confirmation' => 'Vorgatz confirmar la voastra signatura :',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un corrier electronic de confirmacion sus @email@. Per validar la voastra signatura, cau visitar l’adreça web mencionada per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Boanjorn,

Avètz demandat de signar la peticion:
@titre@.

Avètz fornit li informacions seguenti:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar la voastra signatura, basta vos connectar a
l’adreça çai sota (dins lo cas contrari, la voastra demanda
serà refudada) :

    @url@


Mercé de la voastra participacion
',
	'form_pet_nom_site2' => 'Nom dau voastre sit web', # MODIF
	'form_pet_probleme_liens' => 'Vorgatz tornar escriure lo voastre messatge en supprimant lu ligams ipertèxt.',
	'form_pet_probleme_technique' => 'Problèma tecnic, li signaturas son temporàriament arrestadi.',
	'form_pet_signature_validee' => 'La voastra signatura es validada. Mercé !',
	'form_pet_site_deja_enregistre' => 'Aqueu sit es ja registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicada es pas valida.',
	'form_pet_votre_email' => 'La voastra adreça e-mail',
	'form_pet_votre_nom' => 'Lo voastre nom ò pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, lo podètz indicar çai sota',

	// I
	'info_adresse_email' => 'ADREÇA E-MAIL:',
	'info_signature_supprimee' => 'Signatura suprimida',
	'info_signature_supprimee_erreur' => 'Error : aquèu còde de supression correspoande à minga signatura', # MODIF
	'info_site_web' => 'SIT WEB :',

	// L
	'lien_reponse_article' => 'Respoasta à l’article'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la peticion',
	'bouton_radio_pas_petition' => 'Minga de peticion',
	'bouton_radio_petition_activee' => 'Peticion activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',

	// F
	'form_pet_adresse_site' => 'Adreça dau voastre sit', # MODIF
	'form_pet_aucune_signature' => 'Minga de signatura correspoande à-n-aqueu còde...', # MODIF
	'form_pet_confirmation' => 'Vorgatz confirmar la voastra signatura :',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un corrier electronic de confirmacion sus @email@. Per validar la voastra signatura, cau visitar l’adreça web mencionada per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Boanjorn,

Avètz demandat de signar la peticion:
@titre@.

Avètz fornit li informacions seguenti:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar la voastra signatura, basta vos connectar a
l’adreça çai sota (dins lo cas contrari, la voastra demanda
serà refudada) :

    @url@


Mercé de la voastra participacion
',
	'form_pet_nom_site2' => 'Nom dau voastre sit web', # MODIF
	'form_pet_probleme_liens' => 'Vorgatz tornar escriure lo voastre messatge en supprimant lu ligams ipertèxt.',
	'form_pet_probleme_technique' => 'Problèma tecnic, li signaturas son temporàriament arrestadi.',
	'form_pet_signature_validee' => 'La voastra signatura es validada. Mercé !',
	'form_pet_site_deja_enregistre' => 'Aqueu sit es ja registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicada es pas valida.',
	'form_pet_votre_email' => 'La voastra adreça e-mail',
	'form_pet_votre_nom' => 'Lo voastre nom ò pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, lo podètz indicar çai sota',

	// I
	'info_adresse_email' => 'ADREÇA E-MAIL:',
	'info_signature_supprimee' => 'Signatura suprimida',
	'info_signature_supprimee_erreur' => 'Error : aquèu còde de supression correspoande à minga signatura', # MODIF
	'info_site_web' => 'SIT WEB :',

	// L
	'lien_reponse_article' => 'Respoasta à l’article'
);

?>
